# Interacting with the project

Always use `uv run` to run different commands, like pre-commit, tox, pytest,
or the project itself. This will ensure that the dependencies are installed
automatically.

# Testing instructions

- Ensure `tox` passes successfully. Fix any reported issues.
